@@ -8,7 +8,8 @@
 extern "C" {
 #endif
 
-
+PyObject* kth_py_native_chain_output_construct(PyObject* self, PyObject* args);
+PyObject* kth_py_native_chain_output_factory_from_data(PyObject* self, PyObject* args);
 PyObject* kth_py_native_chain_output_is_valid(PyObject* self, PyObject* args);
 PyObject* kth_py_native_chain_output_serialized_size(PyObject* self, PyObject* args);
 PyObject* kth_py_native_chain_output_value(PyObject* self, PyObject* args);
@@ -16,8 +17,8 @@ PyObject* kth_py_native_chain_output_signature_operations(PyObject* self, PyObje
 PyObject* kth_py_native_chain_output_destruct(PyObject* self, PyObject* args);
 PyObject* kth_py_native_chain_output_script(PyObject* self, PyObject* args);
 
-//PyObject* kth_py_native_chain_output_get_hash(PyObject* self, PyObject* args);
-//PyObject* kth_py_native_chain_output_get_index(PyObject* self, PyObject* args);
+//PyObject* kth_py_native_chain_output_hash(PyObject* self, PyObject* args);
+//PyObject* kth_py_native_chain_output_index(PyObject* self, PyObject* args);
 
 PyObject* kth_py_native_chain_output_to_data(PyObject* self, PyObject* args);
 
