@@ -9,10 +9,10 @@ extern "C" {
 #endif
 
 
-PyObject* kth_py_native_chain_output_point_get_hash(PyObject* self, PyObject* args);
+PyObject* kth_py_native_chain_output_point_hash(PyObject* self, PyObject* args);
 PyObject* kth_py_native_chain_output_point_construct(PyObject* self, PyObject* args);
 PyObject* kth_py_native_chain_output_point_construct_from_hash_index(PyObject* self, PyObject* args);
-PyObject* kth_py_native_chain_output_point_get_index(PyObject* self, PyObject* args);
+PyObject* kth_py_native_chain_output_point_index(PyObject* self, PyObject* args);
 PyObject* kth_py_native_chain_output_point_destruct(PyObject* self, PyObject* args);
 
 #ifdef __cplusplus
