@@ -8,6 +8,8 @@
 extern "C" {
 #endif
 
+PyObject* kth_py_native_chain_script_construct(PyObject* self, PyObject* args);
+PyObject* kth_py_native_chain_script_to_data(PyObject* self, PyObject* args);
 PyObject* kth_py_native_chain_script_destruct(PyObject* self, PyObject* args);
 PyObject* kth_py_native_chain_script_is_valid(PyObject* self, PyObject* args);
 PyObject* kth_py_native_chain_script_is_valid_operations(PyObject* self, PyObject* args);
