@@ -7,6 +7,36 @@
 extern "C" {
 #endif
 
+// kth_script_t kth_chain_script_construct(uint8_t* encoded, kth_size_t n, kth_bool_t prefix);
+PyObject* kth_py_native_chain_script_construct(PyObject* self, PyObject* args){
+    char* py_encoded;
+    int py_n;
+    int py_prefix;
+
+    if ( ! PyArg_ParseTuple(args, "y#i", &py_encoded, &py_n, &py_prefix)) {
+        return NULL;
+    }
+
+    kth_script_t res = kth_chain_script_construct((uint8_t*)py_encoded, py_n, py_prefix);
+    return to_py_obj(res);
+}
+
+// uint8_t const* kth_chain_script_to_data(kth_script_t script, kth_bool_t prefix, kth_size_t* out_size);
+PyObject* kth_py_native_chain_script_to_data(PyObject* self, PyObject* args) {
+    PyObject* py_script;
+    int py_prefix;
+
+    if ( ! PyArg_ParseTuple(args, "Oi", &py_script, &py_prefix)) {
+        return NULL;
+    }
+
+    kth_script_t script = (kth_script_t)get_ptr(py_script);
+    kth_size_t out_n;
+    uint8_t* data = (uint8_t*)kth_chain_script_to_data(script, py_prefix, &out_n);
+
+    return Py_BuildValue("y#", data, out_n);
+}
+
 PyObject* kth_py_native_chain_script_destruct(PyObject* self, PyObject* args){
     PyObject* py_script;
 
