@@ -68,8 +68,8 @@ PyMethodDef KnuthNativeMethods[] = {
     // {"node_init_run_sync",  kth_py_native_node_init_run_sync, METH_VARARGS, "..."},
     {"node_init_run_and_wait_for_signal",  kth_py_native_node_init_run_and_wait_for_signal, METH_VARARGS, "..."},
     {"node_signal_stop",  kth_py_native_node_signal_stop, METH_VARARGS, "..."},
-    {"node_get_chain",  kth_py_native_node_get_chain, METH_VARARGS, "Get Blockchain API."},
-    {"node_get_p2p",  kth_py_native_node_get_p2p, METH_VARARGS, "Get P2P Networking API."},
+    {"node_chain",  kth_py_native_node_chain, METH_VARARGS, "Get Blockchain API."},
+    {"node_p2p",  kth_py_native_node_p2p, METH_VARARGS, "Get P2P Networking API."},
 
     {"node_print_thread_id",  kth_py_native_node_print_thread_id, METH_VARARGS, "..."},
 
@@ -101,6 +101,9 @@ PyMethodDef KnuthNativeMethods[] = {
     {"chain_subscribe_transaction",  kth_py_native_chain_subscribe_transaction, METH_VARARGS, "..."},
     {"chain_unsubscribe",  kth_py_native_chain_unsubscribe, METH_VARARGS, "..."},
 
+
+    {"chain_transaction_is_valid",  kth_py_native_chain_transaction_is_valid, METH_VARARGS, "..."},
+    {"chain_transaction_construct",  kth_py_native_chain_transaction_construct, METH_VARARGS, "..."},
     {"chain_transaction_destruct",  kth_py_native_chain_transaction_destruct, METH_VARARGS, "..."},
     {"chain_transaction_factory_from_data",  kth_py_native_chain_transaction_factory_from_data, METH_VARARGS, "..."},
     {"chain_transaction_version",  kth_py_native_chain_transaction_version, METH_VARARGS, "..."},
@@ -127,49 +130,58 @@ PyMethodDef KnuthNativeMethods[] = {
     {"chain_transaction_inputs",  kth_py_native_chain_transaction_inputs, METH_VARARGS, "..."},
     {"chain_transaction_to_data",  kth_py_native_chain_transaction_to_data, METH_VARARGS, "..."},
 
-    {"chain_input_destruct",  kth_py_native_kth_chain_input_destruct, METH_VARARGS, "..."},
-    {"chain_input_is_valid",  kth_py_native_kth_chain_input_is_valid, METH_VARARGS, "..."},
-    {"chain_input_is_final",  kth_py_native_kth_chain_input_is_final, METH_VARARGS, "..."},
-    {"chain_input_serialized_size",  kth_py_native_kth_chain_input_serialized_size, METH_VARARGS, "..."},
-    {"chain_input_sequence",  kth_py_native_kth_chain_input_sequence, METH_VARARGS, "..."},
-    {"chain_input_signature_operations",  kth_py_native_kth_chain_input_signature_operations, METH_VARARGS, "..."},
-    {"chain_input_script",  kth_py_native_kth_chain_input_script, METH_VARARGS, "..."},
-    {"chain_input_previous_output",  kth_py_native_kth_chain_input_previous_output, METH_VARARGS, "..."},
-    //{"chain_input_get_hash",  kth_py_native_kth_chain_input_get_hash, METH_VARARGS, "..."},
-    //{"chain_input_get_index",  kth_py_native_kth_chain_input_get_index, METH_VARARGS, "..."},
-    {"chain_input_to_data",  kth_py_native_kth_chain_input_to_data, METH_VARARGS, "..."},
+    {"chain_input_factory_from_data",  kth_py_native_chain_input_factory_from_data, METH_VARARGS, "..."},
+    {"chain_input_construct",  kth_py_native_chain_input_construct, METH_VARARGS, "..."},
+    {"chain_input_destruct",  kth_py_native_chain_input_destruct, METH_VARARGS, "..."},
+    {"chain_input_is_valid",  kth_py_native_chain_input_is_valid, METH_VARARGS, "..."},
+    {"chain_input_is_final",  kth_py_native_chain_input_is_final, METH_VARARGS, "..."},
+    {"chain_input_serialized_size",  kth_py_native_chain_input_serialized_size, METH_VARARGS, "..."},
+    {"chain_input_sequence",  kth_py_native_chain_input_sequence, METH_VARARGS, "..."},
+    {"chain_input_signature_operations",  kth_py_native_chain_input_signature_operations, METH_VARARGS, "..."},
+    {"chain_input_script",  kth_py_native_chain_input_script, METH_VARARGS, "..."},
+    {"chain_input_previous_output",  kth_py_native_chain_input_previous_output, METH_VARARGS, "..."},
+    //{"chain_input_hash",  kth_py_native_chain_input_hash, METH_VARARGS, "..."},
+    //{"chain_input_index",  kth_py_native_chain_input_index, METH_VARARGS, "..."},
+    {"chain_input_to_data",  kth_py_native_chain_input_to_data, METH_VARARGS, "..."},
 
+    {"chain_input_list_construct_default",  kth_py_native_chain_input_list_construct_default, METH_VARARGS, "..."},
     {"chain_input_list_push_back",  kth_py_native_input_list_push_back, METH_VARARGS, "..."},
     {"chain_input_list_count",  kth_py_native_input_list_count, METH_VARARGS, "..."},
     {"chain_input_list_nth",  kth_py_native_input_list_nth, METH_VARARGS, "..."},
 
+    {"chain_output_construct",  kth_py_native_chain_output_construct, METH_VARARGS, "..."},
+    {"chain_output_factory_from_data",  kth_py_native_chain_output_factory_from_data, METH_VARARGS, "..."},
     {"chain_output_destruct",  kth_py_native_chain_output_destruct, METH_VARARGS, "..."},
     {"chain_output_is_valid",  kth_py_native_chain_output_is_valid, METH_VARARGS, "..."},
     {"chain_output_serialized_size",  kth_py_native_chain_output_serialized_size, METH_VARARGS, "..."},
     {"chain_output_value",  kth_py_native_chain_output_value, METH_VARARGS, "..."},
     {"chain_output_signature_operations",  kth_py_native_chain_output_signature_operations, METH_VARARGS, "..."},
     {"chain_output_script",  kth_py_native_chain_output_script, METH_VARARGS, "..."},
-    //{"chain_output_get_hash",  kth_py_native_chain_output_get_hash, METH_VARARGS, "..."},
-    //{"chain_output_get_index",  kth_py_native_chain_output_get_index, METH_VARARGS, "..."},
+    //{"chain_output_hash",  kth_py_native_chain_output_hash, METH_VARARGS, "..."},
+    //{"chain_output_index",  kth_py_native_chain_output_index, METH_VARARGS, "..."},
     {"chain_output_to_data",  kth_py_native_chain_output_to_data, METH_VARARGS, "..."},
 
-
+    {"chain_output_list_construct_default",  kth_py_native_chain_output_list_construct_default, METH_VARARGS, "..."},
     {"chain_output_list_push_back",  kth_py_native_output_list_push_back, METH_VARARGS, "..."},
     {"chain_output_list_count",  kth_py_native_output_list_count, METH_VARARGS, "..."},
     {"chain_output_list_nth",  kth_py_native_output_list_nth, METH_VARARGS, "..."},
 
     {"chain_merkle_block_destruct",  kth_py_native_chain_merkle_block_destruct, METH_VARARGS, "..."},
-    {"chain_merkle_block_get_header",  kth_py_native_chain_merkle_block_get_header, METH_VARARGS, "..."},
+    {"chain_merkle_block_header",  kth_py_native_chain_merkle_block_header, METH_VARARGS, "..."},
     {"chain_merkle_block_is_valid",  kth_py_native_chain_merkle_block_is_valid, METH_VARARGS, "..."},
     {"chain_merkle_block_hash_count",  kth_py_native_chain_merkle_block_hash_count, METH_VARARGS, "..."},
     {"chain_merkle_block_serialized_size",  kth_py_native_chain_merkle_block_serialized_size, METH_VARARGS, "..."},
     {"chain_merkle_block_total_transaction_count",  kth_py_native_chain_merkle_block_total_transaction_count, METH_VARARGS, "..."},
     {"chain_merkle_block_reset",  kth_py_native_chain_merkle_block_reset, METH_VARARGS, "..."},
 
+
+    {"chain_block_to_data",  kth_py_native_chain_block_to_data, METH_VARARGS, "..."},
+    {"chain_block_construct",  kth_py_native_chain_block_construct, METH_VARARGS, "..."},
+    {"chain_block_factory_from_data",  kth_py_native_chain_block_factory_from_data, METH_VARARGS, "..."},
     {"chain_block_destruct",  kth_py_native_chain_block_destruct, METH_VARARGS, "..."},
     {"chain_block_transactions",  kth_py_native_chain_block_transactions, METH_VARARGS, "..."},
 
-    {"chain_block_get_header",  kth_py_native_chain_block_get_header, METH_VARARGS, "..."},
+    {"chain_block_header",  kth_py_native_chain_block_header, METH_VARARGS, "..."},
     {"chain_block_hash",  kth_py_native_chain_block_hash, METH_VARARGS, "..."},
 
     //TODO(KNUTH-NEW): implement
@@ -194,34 +206,40 @@ PyMethodDef KnuthNativeMethods[] = {
     {"chain_block_is_internal_double_spend",  kth_py_native_chain_block_is_internal_double_spend, METH_VARARGS, "..."},
     {"chain_block_is_valid_merkle_root",  kth_py_native_chain_block_is_valid_merkle_root, METH_VARARGS, "..."},
 
+    {"chain_header_to_data",  kth_py_native_chain_header_to_data, METH_VARARGS, "..."},
+    {"chain_header_construct",  kth_py_native_chain_header_construct, METH_VARARGS, "..."},
+    {"chain_header_is_valid",  kth_py_native_chain_header_is_valid, METH_VARARGS, "..."},
+    {"chain_header_factory_from_data",  kth_py_native_chain_header_factory_from_data, METH_VARARGS, "..."},
     {"chain_header_destruct",  kth_py_native_chain_header_destruct, METH_VARARGS, "..."},
-    {"chain_header_get_version",  kth_py_native_chain_header_get_version, METH_VARARGS, "..."},
+    {"chain_header_version",  kth_py_native_chain_header_version, METH_VARARGS, "..."},
     {"chain_header_set_version",  kth_py_native_chain_header_set_version, METH_VARARGS, "..."},
-    {"chain_header_get_previous_block_hash",  kth_py_native_chain_header_get_previous_block_hash, METH_VARARGS, "..."},
+    {"chain_header_previous_block_hash",  kth_py_native_chain_header_previous_block_hash, METH_VARARGS, "..."},
     //{"chain_header_set_previous_block_hash",  kth_py_native_chain_header_set_previous_block_hash, METH_VARARGS, "..."},
-    {"chain_header_get_merkle",  kth_py_native_chain_header_get_merkle, METH_VARARGS, "..."},
+    {"chain_header_merkle",  kth_py_native_chain_header_merkle, METH_VARARGS, "..."},
     //{"chain_header_set_merkle",  kth_py_native_chain_header_set_merkle, METH_VARARGS, "..."},
-    {"chain_header_get_hash",  kth_py_native_chain_header_get_hash, METH_VARARGS, "..."},
-    {"chain_header_get_timestamp",  kth_py_native_chain_header_get_timestamp, METH_VARARGS, "..."},
+    {"chain_header_hash",  kth_py_native_chain_header_hash, METH_VARARGS, "..."},
+    {"chain_header_timestamp",  kth_py_native_chain_header_timestamp, METH_VARARGS, "..."},
     {"chain_header_set_timestamp",  kth_py_native_chain_header_set_timestamp, METH_VARARGS, "..."},
-    {"chain_header_get_bits",  kth_py_native_chain_header_get_bits, METH_VARARGS, "..."},
+    {"chain_header_bits",  kth_py_native_chain_header_bits, METH_VARARGS, "..."},
     {"chain_header_set_bits",  kth_py_native_chain_header_set_bits, METH_VARARGS, "..."},
-    {"chain_header_get_nonce",  kth_py_native_chain_header_get_nonce, METH_VARARGS, "..."},
+    {"chain_header_nonce",  kth_py_native_chain_header_nonce, METH_VARARGS, "..."},
     {"chain_header_set_nonce",  kth_py_native_chain_header_set_nonce, METH_VARARGS, "..."},
 
     {"chain_history_compact_list_destruct",  kth_py_native_history_compact_list_destruct, METH_VARARGS, "..."},
     {"chain_history_compact_list_count",  kth_py_native_history_compact_list_count, METH_VARARGS, "..."},
     {"chain_history_compact_list_nth",  kth_py_native_history_compact_list_nth, METH_VARARGS, "..."},
-    {"chain_history_compact_get_point_kind",  kth_py_native_history_compact_get_point_kind, METH_VARARGS, "..."},
-    {"chain_history_compact_get_point",  kth_py_native_history_compact_get_point, METH_VARARGS, "..."},
-    {"chain_history_compact_get_height",  kth_py_native_history_compact_get_height, METH_VARARGS, "..."},
-    {"chain_history_compact_get_value_or_previous_checksum",  kth_py_native_history_compact_get_value_or_previous_checksum, METH_VARARGS, "..."},
+    {"chain_history_compact_point_kind",  kth_py_native_history_compact_point_kind, METH_VARARGS, "..."},
+    {"chain_history_compact_point",  kth_py_native_history_compact_point, METH_VARARGS, "..."},
+    {"chain_history_compact_height",  kth_py_native_history_compact_height, METH_VARARGS, "..."},
+    {"chain_history_compact_value_or_previous_checksum",  kth_py_native_history_compact_value_or_previous_checksum, METH_VARARGS, "..."},
 
-    {"chain_point_get_hash",  kth_py_native_point_get_hash, METH_VARARGS, "..."},
+    {"chain_point_hash",  kth_py_native_point_hash, METH_VARARGS, "..."},
     {"chain_point_is_valid",  kth_py_native_point_is_valid, METH_VARARGS, "..."},
-    {"chain_point_get_index",  kth_py_native_point_get_index, METH_VARARGS, "..."},
-    {"chain_point_get_checksum",  kth_py_native_point_get_checksum, METH_VARARGS, "..."},
+    {"chain_point_index",  kth_py_native_point_index, METH_VARARGS, "..."},
+    {"chain_point_checksum",  kth_py_native_point_checksum, METH_VARARGS, "..."},
 
+    {"chain_script_construct",  kth_py_native_chain_script_construct, METH_VARARGS, "..."},
+    {"chain_script_to_data",  kth_py_native_chain_script_to_data, METH_VARARGS, "..."},
     {"chain_script_destruct",  kth_py_native_chain_script_destruct, METH_VARARGS, "..."},
     {"chain_script_is_valid",  kth_py_native_chain_script_is_valid, METH_VARARGS, "..."},
     {"chain_script_is_valid_operations",  kth_py_native_chain_script_is_valid_operations, METH_VARARGS, "..."},
@@ -231,13 +249,13 @@ PyMethodDef KnuthNativeMethods[] = {
     {"chain_script_sigops",  kth_py_native_chain_script_sigops, METH_VARARGS, "..."},
     // {"chain_script_sigops",  kth_py_native_chain_script_sigops, METH_VARARGS, "..."},
 
-    {"chain_output_point_get_hash",  kth_py_native_chain_output_point_get_hash, METH_VARARGS, "..."},
+    {"chain_output_point_hash",  kth_py_native_chain_output_point_hash, METH_VARARGS, "..."},
     //{"chain_point_is_valid",  kth_py_native_point_is_valid, METH_VARARGS, "..."},
-    {"chain_output_point_get_index",  kth_py_native_chain_output_point_get_index, METH_VARARGS, "..."},
+    {"chain_output_point_index",  kth_py_native_chain_output_point_index, METH_VARARGS, "..."},
     {"chain_output_point_construct",  kth_py_native_chain_output_point_construct, METH_VARARGS, "..."},
     {"chain_output_point_construct_from_hash_index",  kth_py_native_chain_output_point_construct_from_hash_index, METH_VARARGS, "..."},
     {"chain_output_point_destruct",  kth_py_native_chain_output_point_destruct, METH_VARARGS, "..."},
-    //{"chain_point_get_checksum",  kth_py_native_point_get_checksum, METH_VARARGS, "..."},
+    //{"chain_point_checksum",  kth_py_native_point_checksum, METH_VARARGS, "..."},
 
     {"chain_compact_block_header",  kth_py_native_chain_compact_block_header, METH_VARARGS, "..."},
     {"chain_compact_block_is_valid",  kth_py_native_chain_compact_block_is_valid, METH_VARARGS, "..."},
@@ -260,9 +278,9 @@ PyMethodDef KnuthNativeMethods[] = {
     {"chain_transaction_list_count",  kth_py_native_chain_transaction_list_count, METH_VARARGS, "..."},
     {"chain_transaction_list_nth",  kth_py_native_chain_transaction_list_nth, METH_VARARGS, "..."},
 
-    {"chain_stealth_compact_ephemeral_public_key_hash",  kth_py_native_stealth_compact_get_ephemeral_public_key_hash, METH_VARARGS, "..."},
-    {"chain_stealth_compact_get_transaction_hash",  kth_py_native_stealth_compact_get_transaction_hash, METH_VARARGS, "..."},
-    {"chain_stealth_compact_get_public_key_hash",  kth_py_native_stealth_compact_get_public_key_hash, METH_VARARGS, "..."},
+    {"chain_stealth_compact_ephemeral_public_key_hash",  kth_py_native_stealth_compact_ephemeral_public_key_hash, METH_VARARGS, "..."},
+    {"chain_stealth_compact_transaction_hash",  kth_py_native_stealth_compact_transaction_hash, METH_VARARGS, "..."},
+    {"chain_stealth_compact_public_key_hash",  kth_py_native_stealth_compact_public_key_hash, METH_VARARGS, "..."},
     {"chain_stealth_compact_list_destruct",  kth_py_native_chain_stealth_compact_list_destruct, METH_VARARGS, "..."},
     {"chain_stealth_compact_list_count",  kth_py_native_chain_stealth_compact_list_count, METH_VARARGS, "..."},
     {"chain_stealth_compact_list_nth",  kth_py_native_chain_stealth_compact_list_nth, METH_VARARGS, "..."},
